Change in osmo-msc[master]: move trans->assignment_done to cc.assignment_started

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Neels Hofmeyr gerrit-no-reply at lists.osmocom.org
Fri Dec 21 00:51:40 UTC 2018


Neels Hofmeyr has uploaded this change for review. ( https://gerrit.osmocom.org/12399


Change subject: move trans->assignment_done to cc.assignment_started
......................................................................

move trans->assignment_done to cc.assignment_started

The flag is set to true when an assignment has been started, and it is only
relevant for a CC transaction. So fix naming and place in cc struct.

Cosmetic preparation for I1f8746e7babfcd3028a4d2c0ba260c608c686c76 and
I0ba216b737909e92080a722db26e3577726c63cb/

Change-Id: I8dacf46141ba0b664e85b0867ade330c97d8495f
---
M include/osmocom/msc/transaction.h
M src/libmsc/msc_mgcp.c
2 files changed, 4 insertions(+), 6 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-msc refs/changes/99/12399/1

diff --git a/include/osmocom/msc/transaction.h b/include/osmocom/msc/transaction.h
index 0760c07..74eaf60 100644
--- a/include/osmocom/msc/transaction.h
+++ b/include/osmocom/msc/transaction.h
@@ -52,9 +52,6 @@
 	/* bearer capabilities (rate and codec) */
 	struct gsm_mncc_bearer_cap bearer_cap;
 
-	/* status of the assignment, true when done */
-	bool assignment_done;
-
 	/* if true, TCH_RTP_CREATE is sent after the
 	 * assignment is done */
 	bool tch_rtp_create;
@@ -71,6 +68,7 @@
 			struct osmo_timer_list timer;
 			struct osmo_timer_list timer_guard;
 			struct gsm_mncc msg;	/* stores setup/disconnect/release message */
+			bool assignment_started;
 		} cc;
 		struct {
 			struct gsm411_smc_inst smc_inst;
diff --git a/src/libmsc/msc_mgcp.c b/src/libmsc/msc_mgcp.c
index 5a8ee79..8e2e7a9 100644
--- a/src/libmsc/msc_mgcp.c
+++ b/src/libmsc/msc_mgcp.c
@@ -951,7 +951,7 @@
 	.event_names = msc_mgcp_fsm_evt_names,
 };
 
 /* Try to invoke call assignment and set trans->assignment_done flag if invoked.
  * This is relevant for already ongoing calls -- scenario:
  *  - subscriber is in an active voice call,
  *  - another call is coming in.
@@ -960,10 +960,10 @@
 int msc_mgcp_try_call_assignment(struct gsm_trans *trans)
 {
 	struct ran_conn *conn = trans->conn;
-	if (trans->assignment_done)
+	if (trans->cc.assignment_started)
 		return 0;
 	LOGPFSMSL(conn->fi, DMGCP, LOGL_INFO, "Starting call assignment\n");
-	trans->assignment_done = true;
+	trans->cc.assignment_started = true;
 	return msc_mgcp_call_assignment(trans);
 }
 
@@ -951,7 +951,7 @@
 };
 
-/* Try to invoke call assignment and set trans->assignment_done flag if invoked.
+/* Try to invoke call assignment and set trans->cc.assignment_started flag if invoked.
  * This is relevant for already ongoing calls -- scenario:
  *  - subscriber is in an active voice call,

-- 
To view, visit https://gerrit.osmocom.org/12399
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-msc
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: I8dacf46141ba0b664e85b0867ade330c97d8495f
Gerrit-Change-Number: 12399
Gerrit-PatchSet: 1
Gerrit-Owner: Neels Hofmeyr <nhofmeyr at sysmocom.de>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20181221/21bfe9b2/attachment.htm>


More information about the gerrit-log mailing list